<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
<context>
    <name>AppSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="42"/>
        <source>Check transfer application will automatically install the corresponding UOS version of the application.</source>
        <translation>ಚಿನ್ನು ಹಂಚಿಕೆ ಅಪ್ಲಿಕೇಶನ್ ಅನ್ನು ಆವತ್ತು ಉಸ್ ವೇರಿಯನ್ಸ್ ಅನ್ನು ಸ್ವಯಂಚಲನೆಯಾಗಿ ಅನ್ವಯಿಸುತ್ತದೆ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="56"/>
        <source>Confirm</source>
        <translation>ಅನುಮತಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="54"/>
        <source>Cancel</source>
        <translation>ರದ್ದುಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Application</source>
        <translation>ಅಪ್ಲಿಕೇಶನ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Recommendation</source>
        <translation>ಪ್ರಸ್ತಾಪಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="102"/>
        <source>Transferable</source>
        <translation>ಹಂಚಿಕೆಯಾಗುವ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="112"/>
        <source>Not Suitable</source>
        <translation>ಅನುಕೂಲಕರವಾಗಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="46"/>
        <source>Select apps to transfer</source>
        <translation>ಹಂಚಿಕೆಗೆ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="47"/>
        <source>Please select the applications to back up</source>
        <translation>ದಯವಿಟ್ಟು, ನಿಮ್ಮ ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಬ್ಯಾಕಪ್ ಮಾಡಲು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="86"/>
        <source>UOS data transfer</source>
        <translation>ಯುಓಎಸ್ ಡೇಟಾ ಹಂಚಿಕೆ</translation>
    </message>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="91"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to UOS, helping you seamlessly replace your system.</source>
        <translation>ಯುಓಎಸ್ ಹಂಚಿಕೆ ಸಾಧನವು ನಿಮ್ಮ ಫೈಲ್‌ಗಳು, ವ್ಯಕ್ತಿಯ ಡೇಟಾ ಮತ್ತು ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಯುಓಎಸ್‌ಗೆ ಒಂದು ಕ್ಲಿಕ್‌ನಲ್ಲಿ ವರ್ತಿಸುವ ಸಾಧ್ಯತೆಯನ್ನು ನೀಡುತ್ತದೆ, ನಿಮ್ಮ ಸಿಸ್ಟಮ್ ಅನ್ನು ಸೌಕ್ತ್ಯತೆಯಿಂದ ಬದಲಾಯಿಸಲು ಸಹಾಯ ಮಾಡುತ್ತದೆ.</translation>
    </message>
</context>
<context>
    <name>ChooseWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="35"/>
        <source>Export to local directory</source>
        <translation>ಲೋಕಲ್ ಡಿರೆಕ್ಟರಿಗೆ ಹಾರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="41"/>
        <source>Select a transfer way</source>
        <translation>ಹಂಚಿಕೆಯ ಮಾರ್ಗವನ್ನು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="56"/>
        <source>Unable to connect to the network， please check your network connection or select export to local directory.</source>
        <translation>ನೆಟ್ವರ್ಕ್‌ಗೆ ಸಂಪರ್ಕಿಸಲಾಗಿಲ್ಲ, ನಿಮ್ಮ ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕವನ್ನು ತಪ್ಪಿಸಿಕೊಳ್ಳಿ ಅಥವಾ ಲೋಕಲ್ ಡಿರೆಕ್ಟರಿಗೆ ಹಾರಿಸಲು ಆಯ್ಕೆಮಾಡಿ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="69"/>
        <source>Next</source>
        <translation>ಮುಂದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="33"/>
        <source>From Windows PC</source>
        <translation>ವಿಂಡೋಸ್ ಪ್ಯಾನಲಿನಿಂದ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="39"/>
        <source>Import from backup files</source>
        <translation>ಬ್ಯಾಕಪ್ ಫೈಲ್‌ಗಳಿಂದ ಆಮ್ಲ್ಯತೆ</translation>
    </message>
</context>
<context>
    <name>ConfigSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="39"/>
        <source>Check transfer configuration will automatically apply to UOS.</source>
        <translation>ಹಂಚಿಕೆಯ ಅನುಕೂಲಗಳನ್ನು ಆವತ್ತು ಉಸ್‌ಗೆ ಸ್ವಯಂಚಲನೆಯಾಗಿ ಅನ್ವಯಿಸುತ್ತದೆ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="51"/>
        <source>Confirm</source>
        <translation>ಅನುಮತಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="49"/>
        <source>Cancel</source>
        <translation>ರದ್ದುಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <source>Browser bookmarks</source>
        <translation>ಬ್ರೌಸರ್ ಬುಕ್ಮಾರ್ಕ್‌ಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Recommendation</source>
        <translation>ಪ್ರಸ್ತಾಪಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="98"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="139"/>
        <source>Transferable</source>
        <translation>ಹಂಚಿಕೆಯಾಗುವ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Personal Settings</source>
        <translation>ವ್ಯಕ್ತಿಯ ಸೆಟ್ಟಿಂಗ್‌ಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="138"/>
        <source>Customized Wallpaper</source>
        <translation>ಕಸ್ಟಮೈಸ್ಡ್ ဝဲ်လား</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="49"/>
        <source>Select the configuration to transfer</source>
        <translation>ಹಂಚಿಕೆಯ ಅನುಕೂಲವನ್ನು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="50"/>
        <source>Please select the configurations to back up</source>
        <translation>ದಯವಿಟ್ಟು, ನಿಮ್ಮ ಅನುಕೂಲಗಳನ್ನು ಬ್ಯಾಕಪ್ ಮಾಡಲು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>ConnectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="36"/>
        <source>Ready to connect</source>
        <translation>ಸಂಪರ್ಕಕ್ಕೆ ಸಿದ್ಧ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="41"/>
        <source>Please open data transfer on Windows, and imput the IP and connect code</source>
        <translation>ದಯವಿಟ್ಟು, ವಿಂಡೋಸ್ ನಲ್ಲಿ ಡೇಟಾ ಹಂಚಿಕೆಯನ್ನು ತೆರೆಯಿರಿ ಮತ್ತು IP ಮತ್ತು ಸಂಪರ್ಕ ಕೋಡ್ ನಮ್ಮನ್ನು ನೀಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="48"/>
        <source>Download Windows client</source>
        <translation>ವಿಂಡೋಸ್ ಕ್ಲಿಯೆಂಟ್ ಡೌನ್ಲೋಡ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="59"/>
        <source>Connect code is expired, please refresh for new code</source>
        <translation>ಕನೆಕ್ಟ್ ಕೋಡ್ ಖಾತ್ರಿಯಾಗಿದೆ, ಹೊಸ ಕೋಡ್ ಪಡೆಯಲು ಮತ್ತೆ ಮುಖ್ಯಾಂಶ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="75"/>
        <source>Back</source>
        <translation>ಮರುಮಾರ್ಪು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="104"/>
        <source>computer</source>
        <translation>ಕಂಪ್ಯೂಟರ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="107"/>
        <source>Local IP</source>
        <translation>ಲೋಕಲ್ ಐಪಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="163"/>
        <source>Refresh</source>
        <translation>ಮುಖ್ಯಾಂಶ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>The code will be expired in</source>
        <translation>ಕೋಡ್ ಖಾತ್ರಿಯಾಗಲಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>please input connect code as soon as possible</source>
        <translation>ಕನೆಕ್ಟ್ ಕೋಡ್ ಅನ್ನು ಬೇಗ ನಮ್ಮ ಪ್ರವೇಶ ಮಾಡಿ</translation>
    </message>
</context>
<context>
    <name>CreateBackupFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="87"/>
        <source>Create data backup</source>
        <translation>ಡೇಟಾ ಬ್ಯಾಕಪ್ ಸೃಷ್ಟಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="95"/>
        <source>File information</source>
        <translation>ಫೈಲ್ ಮಾಹಿತಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="115"/>
        <source>Name</source>
        <translation>ಹೆಸರು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="133"/>
        <source>size:0B</source>
        <translation>ಆಕಾರ:0B</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="152"/>
        <source>Location</source>
        <translation>ಸ್ಥಳ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="162"/>
        <source>(Select Backup Disk)</source>
        <translation>(ಬ್ಯಾಕಪ್ ಡಿಸ್ಕ್ ಆಯ್ಕೆ ಮಾಡಿ)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="187"/>
        <source>Insufficient space in the selected disk, please clean the space</source>
        <translation>ಆಯ್ಕೆ ಮಾಡಿದ ಡಿಸ್ಕ್ ನಲ್ಲಿ ಸ್ಥಳ ಸಾಕಾಗಿಲ್ಲ, ಬೇಗ ಸ್ಥಳವನ್ನು ತೆಗೆದುಹಾಕಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="195"/>
        <source>Backup</source>
        <translation>ಬ್ಯಾಕಪ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="193"/>
        <source>Cancel</source>
        <translation>ವಾಪಸ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="339"/>
        <source>Size:%1</source>
        <translation>ಆಕಾರ:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="382"/>
        <source>local disk</source>
        <translation>ಲೋಕಲ್ ಡಿಸ್ಕ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="388"/>
        <source>%1/%2 available</source>
        <translation>&apos;%1/%2 ಲೈವ್&apos;</translation>
    </message>
</context>
<context>
    <name>CustomMessageBox</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="66"/>
        <source>Reselect</source>
        <translation>ಮತ್ತೆ ಆಯ್ಕೆ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="81"/>
        <source>Continue</source>
        <translation>ನಿರ್ವಹಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>The presence of outstanding transfer tasks between you and the target device has been detected.</source>
        <translation>&gt;-
 ನೀವು ಮತ್ತು ಗುರಿಯಾದ ಉಪಕರಣದ ನಡುವೆ ಪೂರ್ವಭಾವಿ ಹಂತದ ಜಾಹೀರಾತುಗಳನ್ನು ಗುರಿಯಾದ ಉಪಕರಣದ ನಡು ಸೂಚಿಸಲಾಗಿದೆ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>Do you want to continue with the last transfer?</source>
        <translation>ನೀವು ಮುಂಚಿನ ಹಂತದ ಜಾಹೀರಾತುಗಳನ್ನು ಮುಂದುವರಿಸಲು ಬಯಸುತ್ಳಾರಾ?</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="54"/>
        <source>Transfer will be completed in</source>
        <translation>ಹಂತದ ಜಾಹೀರಾತು ಪೂರ್ಣಗೊಳ್ಳಲಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="69"/>
        <source>Try again</source>
        <translation>ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="66"/>
        <source>Back</source>
        <translation>ಮರುಮಾರ್ಪು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="29"/>
        <source>Network Error</source>
        <translation>ನೆಟ್ವರ್ಕ್ ತಪ್ಪು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="30"/>
        <source>Transfer interrupted</source>
        <translation>ಹಂತದ ಜಾಹೀರಾತು ಅಡ್ಡಿಪಟ್ಟಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="32"/>
        <source>The network disconnected, transfer failed, please connect the network and try again</source>
        <translation>&gt;-
 ನೆಟ್ವರ್ಕ್ ತಡೆಗಟ್ಟಿದೆ, ಹಂತದ ಜಾಹೀರಾತು ಅನುಕೂಲಕ್ಕೆ ಬಾರಿಸಿ, ನೆಟ್ವರ್ಕ್ ಸಂಪರ್ಕನ್ನು ಮತ್ತೆ ಸ್ಥಾಪಿಸಿ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="34"/>
        <source>Insufficient space in UOS, please clear at least %1 GB and try again</source>
        <translation>ಯೂಒಎಸ್ ನ್ನಲ್ಲಿ ಸ್ಥಳವನ್ನು ಸಾಕಾಗಿಲ್ಲ, ಕನಿಷ್ಠ %1 ಜಿಬಿ ಸ್ಥಳವನ್ನು ತೆಗೆದುಹಾಕಿ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="36"/>
        <source>Insufficient space in UOS, Please reserve enough space</source>
        <translation>ಅಲ್ಲಿ ಸ್ಪೇಸ್ ಇಲ್ಲ, ಸ್ಪೇಸ್ ನ್ನು ಸುರಕ್ಷತೆಯಿಂದ ಸಂಗ್ರಹಿಸಲು ನಿಮ್ಮ ಅಗತ್ಯವಿರುವ ಸ್ಪೇಸ್ ನ್ನು ಸುರಕ್ಷತೆಯಿಂದ ಸಂಗ್ರಹಿಸಿ</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Name</source>
        <translation>ಹೆಸರು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Size</source>
        <translation>ಆಕಾರ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="60"/>
        <source>When transfer completed, the data will be placed in the user&apos;s home directory</source>
        <translation>ಡೇಟಾ ಪರಿವರ್ತನೆಯಾದಾಗ, ಡೇಟಾ ಬಳಕೆದಾರನ ಹೋಮ್ ಡಿರೆಂಟರಿಗೆ ಸ್ಥಾಪಿಸಲಾಗುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="73"/>
        <source>Confirm</source>
        <translation>ಅನುಮೋದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="71"/>
        <source>Cancel</source>
        <translation>ವಾಪಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="56"/>
        <source>Select the file to transfer</source>
        <translation>ಪರಿವರ್ತನೆಗೆ ಅಗತ್ಯವಿರುವ ಫೈಲ್ ಅನ್ನು ಆಯ್ചು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="57"/>
        <source>Please select the files to back up</source>
        <translation>ನಿಮ್ಮ ಫೈಲ್ ಗಳನ್ನು ಬ್ಯಾಕಪ್ ಗೆ ಆಯ್ಚು</translation>
    </message>
</context>
<context>
    <name>NetworkDisconnectionWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="34"/>
        <source>The network has been disconnected. Please check your network</source>
        <translation>ನೆಟ್ವರ್ಕ್ ಅನ್ನು ತೆಗೆದುಹಾಕಲಾಗಿದೆ. ನಿಮ್ಮ ನೆಟ್ವರ್ಕ್ ಅನ್ನು ತಪ್ಪು ಪರಿಶೀಲಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="40"/>
        <source>Back</source>
        <translation>ವಾಪಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="41"/>
        <source>Try again</source>
        <translation>ನೀರಿನ ಬಗ್ಗೆ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ProcessWindow</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="297"/>
        <source>Installing</source>
        <translation>ಸ್ಥಾಪನೆ</translation>
    </message>
</context>
<context>
    <name>PromptWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="29"/>
        <source>Before tranfer</source>
        <translation>ಪರಿವರ್ತನೆಯ ಮೊದಲು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="34"/>
        <source>Data transfer requires some time, to avoid interrupting the migration due to low battery, please keep connect to the  power.</source>
        <translation>ಡೇಟಾ ಪರಿವರ್ತನೆಯ ಕೆಲಸಕ್ಕೆ ಕೆಲವು ಸಮಯ ಅಗತ್ಯವಿರುತ್ತದೆ, ಕಮ್ಯೂನಿಕೇಶನ್ ಕೆಲಸಕ್ಕೆ ಬ್ಯಾಟರಿ ಕಡಿಮೆಯಾದಾಗ ಅಡ್ಡಿಪಡಿಸಲು ನಿಮ್ಮ ಬ್ಯಾಟರಿಗೆ ಸುರಕ್ಷತೆಯಿಂದ ಸಂಪರ್ಕ ಉಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="36"/>
        <source>Other applications may slowdown the transfer speed. For smoother experience, please close other applications.</source>
        <translation>ಇತರ ಅಪ್ಲಿಕೇಶನ್ ಗಳು ಪರಿವರ್ತನೆಯ ವೇಗವನ್ನು ಕಡಿಮೆ ಮಾಡಬಹುದು. ಸುಸ್ಥಿರ ಅನುಭವಕ್ಕೆ, ಇತರ ಅಪ್ಲಿಕೇಶನ್ ಗಳನ್ನು ಮುಚ್ಚಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="38"/>
        <source>For the security of your transfer, please use a trusted network.</source>
        <translation>ನಿಮ್ಮ ಪರಿವರ್ತನೆಯ ಸುರಕ್ಷತೆಗಾಗಿ, ನಿಮಗೆ ಅನುಮತಿಸಲಾದ ನೆಟ್ವರ್ಕ್ ಅನ್ನು ಬಳಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="62"/>
        <source>Back</source>
        <translation>ವಾಪಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="64"/>
        <source>Confirm</source>
        <translation>ಅನುಮೋದಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ReadyWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="48"/>
        <source>Ready to connect</source>
        <translation>ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="52"/>
        <source>IP</source>
        <translation>ಐಪಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="59"/>
        <source>Please input the IP of UOS</source>
        <translation>ಐಪಿ ಅನ್ನು ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ ಅನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="79"/>
        <source>Please open data transfer on UOS, and get the IP</source>
        <translation>ಐಪಿ ಅನ್ನು ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ ಅನ್ನು ಪಡೆಯಲು ಐಪಿ ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ ಅನ್ನು ತೆರೆಯಿರಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="85"/>
        <source>Connect code</source>
        <translation>ಸಂಪರ್ಕ ಕೋಡ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="95"/>
        <source>Please input the connect code on UOS</source>
        <translation>ಐಪಿ ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ ಅನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="118"/>
        <source>Back</source>
        <translation>ವಾಪಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="33"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="112"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="167"/>
        <source>connect...</source>
        <translation>ಸಂಪರ್ಕ...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="120"/>
        <source>Connect</source>
        <translation>ಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="258"/>
        <source>Failed to connect, please check your input</source>
        <translation>ಸಂಪರ್ಕ ವಿಫಲ, ನಿಮ್ಮ ಪ್ರವೇಶವನ್ನು ಪರಿಶೀಲಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ResultDisplayWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="128"/>
        <source>Transfer completed partially</source>
        <translation>ಪರಿವರ್ತನೆಯಾದ ಪೂರ್ಣ ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="32"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="125"/>
        <source>Transfer completed</source>
        <translation>ಪರಿವರ್ತನೆಯಾದ ಪೂರ್ಣ ಪ್ರಮಾಣಿತ ಸಂಪರ್ಕ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="38"/>
        <source>Partial information migration failed, please go to UOS for manual transfer</source>
        <translation>ಪಾರ್ಶಲ್ ಮಾಹಿತಿ ಮಾನ್ಯತಾ ವಿಫಲವಾಯಿತು, ಮಾನ್ಯತೆಯನ್ನು ಕೈಗೊಳ್ಳಲು UOS ಗೆ ಹೋಗಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="50"/>
        <source>Back</source>
        <translation>ವಾಪಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="52"/>
        <source>Exit</source>
        <translation>ಮುಚ್ಚು</translation>
    </message>
</context>
<context>
    <name>SelectItem</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="216"/>
        <source>Selected:0</source>
        <translation>ಆಯ್ಕೆ:0</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="239"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="241"/>
        <source>Selected:%1</source>
        <translation>ಆಯ್ಕೆ:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="304"/>
        <source>Edit</source>
        <translation>ಸುಧಾರಣೆ</translation>
    </message>
</context>
<context>
    <name>SelectMainWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="90"/>
        <source>File</source>
        <translation>ಅಖಿಲೋಪ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="95"/>
        <source>App</source>
        <translation>ಆಪ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="97"/>
        <source>Config</source>
        <translation>ಕಂಪ್ಯೂಟರ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="112"/>
        <source>Back</source>
        <translation>ವಾಪಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="72"/>
        <source>Select data to transfer</source>
        <translation>ವರ್ಗಾವಣೆಗೆ ಡೇಟಾ ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="73"/>
        <source>Please select the content to back up</source>
        <translation>ವರ್ಗಾವಣೆಗೆ ಆಯ್ಕೆಮಾಡಲಾಗದ ಹಾಗೆ ಹೊರಗಡೆ ಮಾಹಿತಿಯನ್ನು ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="74"/>
        <source>Start transfer</source>
        <translation>ವರ್ಗಾವಣೆಯನ್ನು ಆರಂಭಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="75"/>
        <source>Next</source>
        <translation>ಮುಂದು</translation>
    </message>
</context>
<context>
    <name>SettingHelper</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Profiles</source>
        <translation>ಪ್ರೊಫೈಲ್ಸ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Wrong or missing profile</source>
        <translation>ಅಸ್ಥಿತ್ಯದ ಅಥವಾ ಕೆಳಗಿನ ಪ್ರೊಫೈಲ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <source>My Wallpaper</source>
        <translation>ನನ್ನ ಬೆಕ್ಕಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="234"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer completed</source>
        <translation>ವರ್ಗಾವಣೆ ಪೂರ್ಣಗೊಂಡಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Browser Bookmarks</source>
        <translation>ಬ್ರೌಸರ್ ಬುಕ್ಮಾರ್ಕ್ಸ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <source>BrowserBookMark</source>
        <translation>ಬ್ರೌಸರ್ ಬುಕ್ಮಾರ್ಕ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="176"/>
        <source>is installed</source>
        <translation>ಇನ್ಸ್ಟಾಲ್ ಆಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="200"/>
        <source>Installing</source>
        <translation>ಇನ್ಸ್ಟಾಲ್ ಆಗುತ್ತಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer failed</source>
        <translation>ವರ್ಗಾವಣೆ ವಿಫಲವಾಯಿತು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <source>Format error</source>
        <translation>ಫಾರ್ಮೇಟ್ ತಪ್ಪು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Setup failed, configuration can be imported manually</source>
        <translation>ಸೆಟಪ್ ವಿಫಲವಾಯಿತು, ಕಂಪ್ಯೂಟರ್ ಮಾನ್ಯತೆಯನ್ನು ಕೈಗೊಳ್ಳಲು ಮಾನ್ಯತೆಯನ್ನು ಸ್ವಯಂ ಅನ್ವಯಿಸಬಹುದು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="157"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="188"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="238"/>
        <source>Installation failed, please go to the app store to install</source>
        <translation>ಇನ್ಸ್ಟಾಲ್ ವಿಫಲವಾಯಿತು, ಆಪ್ ಸ್ಟೋರ್ ಗೆ ಹೋಗಿ ಇನ್ಸ್ಟಾಲ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="249"/>
        <source>Transfer Complete</source>
        <translation>ವರ್ಗಾವಣೆ ಪೂರ್ಣಗೊಂಡಿದೆ</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="21"/>
        <source>Videos</source>
        <translation>ವಿಡಿಯೋಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="22"/>
        <source>Pictures</source>
        <translation>ಚಿತ್ರಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="23"/>
        <source>Documents</source>
        <translation>ದಾಸ್ತಾನುಗಳು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="24"/>
        <source>Downloads</source>
        <translation>ಪರಿಶೀಲಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="25"/>
        <source>Music</source>
        <translation>ಹಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="26"/>
        <source>Desktop</source>
        <translation>ಡೆಸ್ಕ್ಟಾಪ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="80"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="351"/>
        <source>Select:%1</source>
        <translation>ಆಯ್ಕೆಮಾಡಿ:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="225"/>
        <source>local disk</source>
        <translation>ವಿಶೇಷ ಡಿಸ್ಕ್</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="35"/>
        <source>UOS data transfer</source>
        <translation>ಯುಒಎಸ್ ಡೇಟಾ ಪರಿವರ್ತನೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="39"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to
UOS, helping you seamlessly replace your system.</source>
        <translation>ಯುಒಎಸ್ ಪರಿವರ್ತನೆ ಸಾಧನವು ನಿಮ್ಮ ಫೈಲ್‌ಗಳು, ವ್ಯಕ್ತಿಯ ಡೇಟಾ ಮತ್ತು ಅಪ್ಲಿಕೇಶನ್‌ಗಳನ್ನು ಒಂದು ಕ್ಲಿಕ್ ಮೂಲಕ ಯುಒಎಸ್‌ಗೆ ಪರಿವರ್ತನೆ ಮಾಡಲು ಅನುಮತಿ ನೀಡು, ನಿಮ್ಮ ಸಿಸ್ಟಮ್‌ನ್ನು ಸುಗಮವಾಗಿ ಬದಲಾಯಿಸಲು ಸಹಾಯ ಮಾಡುತ್ತದೆ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="46"/>
        <source>Next</source>
        <translation>ಮುಂದೆ</translation>
    </message>
</context>
<context>
    <name>TransferHandle</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/transferworker.cpp" line="326"/>
        <source>Transfering</source>
        <translation>ಪರಿವರ್ತನೆ</translation>
    </message>
</context>
<context>
    <name>TransferringWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="42"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="193"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="230"/>
        <source>Transferring...</source>
        <translation>ಪರಿವರ್ತನೆ...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="57"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="191"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="229"/>
        <source>Calculationing...</source>
        <translation>ಅಂಶಾಂಶ ಮಾಡುತ್ತಿದೆ...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="63"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="132"/>
        <source>Show processes</source>
        <translation>ಪ್ರಕ್ರಿಯೆಗಳನ್ನು ತೋರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="119"/>
        <source>Hide processes</source>
        <translation>ಪ್ರಕ್ರಿಯೆಗಳನ್ನು ಕಾಣದಿರಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="154"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="195"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>ಪರಿವರ್ತನೆ %1 ನಿಮಿಷಗಳಲ್ಲಿ ಪೂರ್ಣಗೊಳ್ಳುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="171"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="243"/>
        <source>Transfering</source>
        <translation>ಪರಿವರ್ತನೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="199"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>ಪರಿವರ್ತನೆ %1 ಸೆಕೆಂಡ್‌ನಿಂದ ಪೂರ್ಣಗೊಳ್ಳುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="202"/>
        <source>Transfer will be completed in --</source>
        <translation>ಪರಿವರ್ತನೆ -- ನಿಮಿಷಗಳಲ್ಲಿ ಪೂರ್ಣಗೊಳ್ಳುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <source>Decompressing</source>
        <translation>ಪ್ರತ್ಯಕ್ಷಗೊಳಿಸು</translation>
    </message>
</context>
<context>
    <name>UnzipWorker</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="126"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="137"/>
        <source>Decompressing</source>
        <translation>ಪ್ರತ್ಯಕ್ಷಗೊಳಿಸು</translation>
    </message>
</context>
<context>
    <name>UploadFileFrame</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="197"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="256"/>
        <source>Drag file here </source>
        <translation>ಫೈಲ್ ಇಲ್ಲಿ ತೆಗೆದುಕೊಳ್ಳಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="202"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="257"/>
        <source>Import file</source>
        <translation>ಫೈಲ್ ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="276"/>
        <source>Only .zip is supported, please</source>
        <translation>ಮಾತ್ರ .zip ಆಯ್ಕೆಮಾಡಿ, ಬೇಕಾದರೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="277"/>
        <source>reselect</source>
        <translation>ಮತ್ತೆ ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>select zip file</source>
        <translation>ಫೈಲ್ ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>ZIP file (*.zip)</source>
        <translation>ZIP ಫೈಲ್ (*.zip)</translation>
    </message>
</context>
<context>
    <name>UploadFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="40"/>
        <source>Select data transfer file</source>
        <translation>ಡೇಟಾ ಪರಿವರ್ಥನೆ ಫೈಲ್ ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="49"/>
        <source>File error, cannot transfer, please reselect</source>
        <translation>ಫೈಲ್ ತಪ್ಪು, ಪರಿವರ್ತನೆ ಮಾಡಲಾಗುವುದಿಲ್ಲ, ಬೇಕಾದರೆ ಮತ್ತೆ ಆಯ್ಕೆಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="62"/>
        <source>Back</source>
        <translation>ಕೆಳಗೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="64"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="108"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="113"/>
        <source>Next</source>
        <translation>ಮುಂದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="69"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="76"/>
        <source>Retry</source>
        <translation>ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="122"/>
        <source>The file is corrupted and cannot be migrated. Please replace it with a backup file.</source>
        <translation>ದೋಷಪೂರ್ಣ ಅಥವಾ ಮಿಗ್ರೇಟ್ ಮಾಡಲು ಸಾಧ್ಯವಿಲ್ಲ. ಬ್ಯಾಕಪ್ ಫೈಲ್ ಅನ್ನು ಬದಲಾಯಿಸಲು ಬ್ಯಾಕಪ್ ಫೈಲ್ ಅನ್ನು ಬದಲಾಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="133"/>
        <source>Insufficient space on UOS. Please reserve at least %1G of space and try again.</source>
        <translation>UOS ಗೆ ಸ್ಥಳವಿಲ್ಲ. ಕನಿಷ್ಠ %1G ಅಂತರ್ಭುಕ್ತ ಸ್ಥಳವನ್ನು ಸಂಗ್ರಹಿಸಿ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ</translation>
    </message>
</context>
<context>
    <name>UserSelectFileSize</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/userselectfilesize.cpp" line="22"/>
        <source>Calculating</source>
        <translation>ಲೆಕ್ಕಾಚಾರ</translation>
    </message>
</context>
<context>
    <name>WaitTransferWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="32"/>
        <source>Waiting for transfer...</source>
        <translation>ವರ್ಗಾವಣೆಯನ್ನು ವ etcರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="37"/>
        <source>Please select the data to transfer on Windows</source>
        <translation>ದಯವಿಟ್ಟು, ವಿನ್ಡೋಸ್ ಮೇಲೆ ವರ್ಗಾವಣೆಗೆ ಬರುವ ಡೇಟಾವನ್ನು ಆಯ್ಕೆ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="47"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="98"/>
        <source>Cancel</source>
        <translation>ವಿಠಾರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="99"/>
        <source>Close</source>
        <translation>ಮುಚ್ಚಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="101"/>
        <source>This operation will clear the transmission progress, Do you want to continue.</source>
        <translation>ಈ ಕ್ರಮವು ವರ್ಗಾವಣೆಯ ಪ್ರಗತಿಯನ್ನು ತೊರೆಯುತ್ತದೆ, ಮತ್ತೆ ಮುಂದುವರಿಸಲು ಬಯಸುತ್ತೀರಾ?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="102"/>
        <source>This operation is not recoverable</source>
        <translation>ಈ ಕ್ರಮವು ಪುನರುವಾರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessResultWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="32"/>
        <source>Exit</source>
        <translation>ಬರುವುದನ್ನು ಬ್ರೇಕ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="49"/>
        <source>Back</source>
        <translation>ಮೊದಲು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="84"/>
        <source>Back up succeed</source>
        <translation>ಬ್ಯಾಕಪ್ ಯಶಸ್ವಿಯಾಯಿತು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="90"/>
        <source>Congratulations, Your Information has been Successfully Backed Up.</source>
        <translation>ಅಭಿನಂದನೆಗಳು, ನಿಮ್ಮ ಮಾಹಿತಿಯು ಯಶಸ್ವಿಯಾಗಿ ಬ್ಯಾಕಪ್ ಮಾಡಲ್ಪಟ್ಟಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="95"/>
        <source>Go to View</source>
        <translation>ಪ್ರದರ್ಶನಕ್ಕೆ ಹೋಗಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="120"/>
        <source>Back up failed</source>
        <translation>ಬ್ಯಾಕಪ್ ವಿಫಲವಾಯಿತು</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="44"/>
        <source>Packing  %1</source>
        <translation>ಪ್ಯಾಕಿಂಗ್ %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="53"/>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="101"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>ವರ್ಗಾವಣೆ %1 ನಿಮಿಷಗಳಲ್ಲಿ ಪೂರ್ಣಗೊಳ್ಳುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="56"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>ವರ್ಗಾವಣೆ %1 ಸೆಕೆಂಡ್‌ಗಳಲ್ಲಿ ಪೂರ್ಣಗೊಳ್ಳುತ್ತದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="84"/>
        <source>Creating Backup File...</source>
        <translation>ಬ್ಯಾಕಪ್ ಫೈಲ್ ಸೃಷ್ಟಿಸುತ್ತಿದೆ...</translation>
    </message>
</context>
<context>
    <name>ZipWork</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="283"/>
        <source>%1 File compression failed</source>
        <translation>&apos;%1 ಫೈಲ್ ಸಂಪಾಚ್ ವಿಫಲವಾಯಿತು&apos;</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="213"/>
        <source>Back up file done</source>
        <translation>ಬ್ಯಾಕಪ್ ಫೈಲ್ ಪೂರ್ಣಗೊಂಡಿದೆ</translation>
    </message>
</context>
<context>
    <name>data_transfer_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/linux/mainwindow_p_linux.cpp" line="32"/>
        <source>UOS data transfer</source>
        <translation>UOS ಡೇಟಾ ವರ್ಗಾವಣೆ</translation>
    </message>
</context>
</TS>